drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 0b6520c4acbfbb656f00d0fab11289899614494f
Author:     Luboš Luňák <l.lu...@collabora.com>
AuthorDate: Wed Aug 31 17:54:34 2022 +0200
Commit:     Luboš Luňák <l.lu...@collabora.com>
CommitDate: Thu Sep 1 12:01:51 2022 +0200

    explicitly use BmpScaleFlag::NearestNeighbor when wanted
    
    That is the algorithm that doesn't change colors, BmpScaleFlag::Fast
    works the same way only because it's mapped to this algorithm
    (which may not necessarily be the case forever).
    
    Change-Id: Ibebfff668eaa1da93963f8e8601fec51cfdfca34
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/139128
    Tested-by: Jenkins
    Reviewed-by: Luboš Luňák <l.lu...@collabora.com>

diff --git a/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx 
b/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx
index 0cc5be1bd532..da3621aa189c 100644
--- a/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx
+++ b/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx
@@ -50,8 +50,8 @@ AlphaMask ProcessAndBlurAlphaMask(const Bitmap& rMask, double 
fErodeDilateRadius
         aSize.setWidth(aSize.Width() / 2);
     }
 
-    // BmpScaleFlag::Fast is important for following color replacement
-    mask.Scale(fScale, fScale, BmpScaleFlag::Fast);
+    // BmpScaleFlag::NearestNeighbor is important for following color 
replacement
+    mask.Scale(fScale, fScale, BmpScaleFlag::NearestNeighbor);
 
     if (fErodeDilateRadius > 0)
         BitmapFilter::Filter(mask, BitmapDilateFilter(fErodeDilateRadius));

Reply via email to